from setuptools import setup

setup(
    name='tycoon_fast_hist',
    version='0.1.0',
    description='fast hist realization',
    author='Nikita Siniachenko',
    author_email='mosson2001@gmail.com',
    url='https://github.com/shuds13/pyexample',
    packages=['fast_hist_package'],
    install_requires=['numpy==1.17.3',
                      'matplotlib==3.4.3'
                      ],
    classifiers=[
        
    ]
)

